package
module
Version:
v0.0.0-...-83d6d81
Opens a new window with list of versions in this module.
Published: May 19, 2021
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
README
¶
Documentation
¶
func ToMap(v interface{}, tag string) map[string]interface{}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.